.. include:: ../../README.rst
   :end-before: .. local-substitutions


.. toctree::
   :hidden:
   :maxdepth: 2

   Home <self>
   installation
   usage
   configuration
   features
   components
   notebooks
   api
   migration
   changelog

.. |banner| image:: /_images/BlueETL.jpeg
